import { ExtractJwt, Strategy } from 'passport-jwt';
import { PassportStrategy } from '@nestjs/passport';
import { Injectable, UnauthorizedException } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { AuthService } from '../auth.service';
import { Request } from 'express';
import { UserTokenPayload } from '../interfaces/user-token-payload.interface';
import { UserTokenData } from '../interfaces/user-token-data.interface';

@Injectable()
export class JwtRefreshStrategy extends PassportStrategy(
  Strategy,
  'jwt-refresh',
) {
  constructor(
    configService: ConfigService,
    private readonly authService: AuthService,
  ) {
    super({
      jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
      ignoreExpiration: false,
      secretOrKey: configService.get<string>('JWT_REFRESH_SECRET'),
      passReqToCallback: true,
    });
  }

  async validate(
    req: Request,
    payload: UserTokenPayload,
  ): Promise<UserTokenData> {
    const isValid = await this.authService.validateRefreshToken(
      ExtractJwt.fromAuthHeaderAsBearerToken()(req),
    );
    if (!isValid) throw new UnauthorizedException();

    return { id: payload.sub, username: payload.username };
  }
}
